System.register('bundle', [], (function (exports) {
	'use strict';
	return {
		execute: (function () {

			var value = exports('default', global);

			console.log(value);

		})
	};
}));
